@@ -161,7 +161,7 @@ std::optional<int> asst::FightTimesTaskPlugin::change_series(int sanity_current,
     }
 
     auto ret = select_series(true);
-    if (!ret && m_is_medicine_exhausted) { // 药品用完, 且没有次数可用, 刷理智结束
+    if (!ret && m_is_medicine_exhausted) { // 药品用完, 且没有次数可用, 理智作战结束
         m_task_ptr->set_enable(false);
     }
     else if (!ret) {
