@@ -15,8 +15,11 @@ public:
 
     void set_enable_clue_exchange(bool value) noexcept { m_enable_clue_exchange = value; }
 
+    void set_send_clue(bool value) noexcept { m_send_clue = value; }
+
 protected:
     virtual bool _run() override;
+    virtual bool on_run_fails() override;
 
 private:
     virtual int operlist_swipe_times() const noexcept override { return 4; }
@@ -35,5 +38,6 @@ private:
 
     bool m_receive_message_board = true;
     bool m_enable_clue_exchange = true;
+    bool m_send_clue = true;
 };
 }
