@@ -1,9 +1,11 @@
 #pragma once
-#include <set>
+
+#include <optional>
 
 #include "Common/AsstBattleDef.h"
 #include "MaaUtils/NoWarningCVMat.hpp"
 #include "Task/AbstractTask.h"
+#include "Ui/BattleQuickFormation.h"
 #include "Ui/SupportList.h"
 #include "Vision/TemplDetOCRer.h"
 
@@ -14,6 +16,7 @@ class BattleFormationTask : public AbstractTask
 {
 public:
     using AbstractTask::AbstractTask;
+    BattleFormationTask(const AsstCallback& callback, Assistant* inst, std::string_view task_chain);
     virtual ~BattleFormationTask() override = default;
 
     enum class Filter
@@ -32,6 +35,7 @@ public:
 
     struct QuickFormationOper : public asst::TemplDetOCRer::Result
     {
+        battle::Role role = battle::Role::Unknown;
         bool is_selected = false; // 是否选中
     };
 
@@ -103,6 +107,10 @@ protected:
     bool add_trust_operators();
     // 选择当前页中的干员, return 是否继续翻页
     bool select_opers_in_cur_page(const std::vector<OperGroup*>& groups);
+    // 检查干员等级
+    bool check_oper_level(const cv::Mat& image, asst::Rect flag, const battle::OperUsage& oper, bool ignore);
+    // 检查并选中技能, return 技能是否达到要求
+    bool check_and_select_skill(const battle::OperUsage& oper, bool ignore, int delay);
     void swipe_page();
     void swipe_to_the_left(int times = 2);
     bool confirm_selection();
@@ -151,5 +159,11 @@ protected:
     bool m_used_support_unit = false; // 是否已经招募助战干员
     // ———————— 以下变量为指定助战干员设置，仅当 m_support_unit_usage == SupportUnitUsage::Specific 时有效 ————————
     battle::RequiredOper m_specific_support_unit;
+
+private:
+    static constexpr battle::Role Roles[] = { battle::Role::Caster,  battle::Role::Medic,   battle::Role::Pioneer,
+                                              battle::Role::Warrior, battle::Role::Special, battle::Role::Tank,
+                                              battle::Role::Sniper,  battle::Role::Support };
+    BattleQuickFormation m_quick_formation_ui;
 };
 } // namespace asst
