@@ -1,7 +1,7 @@
 #include "StageDropsImageAnalyzer.h"
 
+#include <boost/regex.hpp>
 #include <numbers>
-#include <regex>
 
 #include <ranges>
 
@@ -54,6 +54,7 @@ bool asst::StageDropsImageAnalyzer::analyze_stage_code()
 {
     LogTraceFunction;
 
+    static const std::string invalid_stage_code = "_INVALID_";
     std::string stage_code;
     Rect text_rect;
 
@@ -69,7 +70,7 @@ bool asst::StageDropsImageAnalyzer::analyze_stage_code()
     }
 
     // 如果不带 '-'，用非 char 模型再识别一次（适配剿灭/活动等特殊关卡码）
-    if (stage_code.find('-') == std::string::npos) {
+    if (stage_code != invalid_stage_code && stage_code.find('-') == std::string::npos) {
         RegionOCRer analyzer(m_image);
         analyzer.set_task_info("StageDrops-StageName");
         analyzer.set_use_char_model(false);
@@ -136,9 +137,9 @@ bool asst::StageDropsImageAnalyzer::analyze_times()
     std::string raw_str = rec_analyzer.get_result().text;
     Log.info(__FUNCTION__, "raw_str", raw_str);
 
-    std::regex re(R"(\d+)");
-    std::smatch match;
-    if (!std::regex_search(raw_str, match, re)) {
+    boost::regex re(R"([0-9]+)");
+    boost::smatch match;
+    if (!boost::regex_search(raw_str, match, re)) {
         m_times = -2;
         Log.error(__FUNCTION__, "regex_search failed");
         return false;
@@ -768,7 +769,7 @@ std::optional<asst::TextRect>
     const auto& color_scale = std::get<MatchTaskInfo::GrayRange>(task_ptr->color_scales.front());
 
     Rect quantity_roi = roi.move(task_ptr->roi);
-    cv::Mat quantity_img = m_image(make_rect<cv::Rect>(quantity_roi));
+    cv::Mat quantity_img = m_image(make_rect<cv::Rect>(correct_rect(quantity_roi, m_image)));
 
     cv::Mat gray, bin;
     cv::cvtColor(quantity_img, gray, cv::COLOR_BGR2GRAY);
